==> openshift-model-machineconfig-6.7.2-sources.jar: io/fabric8/openshift/api/model/machineconfig/v1/MachineConfigPoolBuilder.java <==
package io.fabric8.openshift.api.model.machineconfig.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class MachineConfigPoolBuilder extends MachineConfigPoolFluentImpl<MachineConfigPoolBuilder> implements VisitableBuilder<MachineConfigPool,MachineConfigPoolBuilder>{
  public MachineConfigPoolBuilder() {
    this(false);
  }
  public MachineConfigPoolBuilder(Boolean validationEnabled) {
    this(new MachineConfigPool(), validationEnabled);
  }
  public MachineConfigPoolBuilder(MachineConfigPoolFluent<?> fluent) {
    this(fluent, false);
  }
  public MachineConfigPoolBuilder(MachineConfigPoolFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new MachineConfigPool(), validationEnabled);
  }
  public MachineConfigPoolBuilder(MachineConfigPoolFluent<?> fluent,MachineConfigPool instance) {
    this(fluent, instance, false);
  }
  public MachineConfigPoolBuilder(MachineConfigPoolFluent<?> fluent,MachineConfigPool instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
      fluent.withSpec(instance.getSpec());
      fluent.withStatus(instance.getStatus());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public MachineConfigPoolBuilder(MachineConfigPool instance) {
    this(instance,false);
  }
  public MachineConfigPoolBuilder(MachineConfigPool instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
      this.withStatus(instance.getStatus());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  MachineConfigPoolFluent<?> fluent;
  Boolean validationEnabled;
  public MachineConfigPool build() {
    MachineConfigPool buildable = new MachineConfigPool(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> openshift-model-machineconfig-6.8.0-sources.jar: io/fabric8/openshift/api/model/machineconfig/v1/MachineConfigPoolBuilder.java <==
package io.fabric8.openshift.api.model.machineconfig.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class MachineConfigPoolBuilder extends MachineConfigPoolFluent<MachineConfigPoolBuilder> implements VisitableBuilder<MachineConfigPool,MachineConfigPoolBuilder>{
  public MachineConfigPoolBuilder() {
    this(false);
  }
  public MachineConfigPoolBuilder(Boolean validationEnabled) {
    this(new MachineConfigPool(), validationEnabled);
  }
  public MachineConfigPoolBuilder(MachineConfigPoolFluent<?> fluent) {
    this(fluent, false);
  }
  public MachineConfigPoolBuilder(MachineConfigPoolFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new MachineConfigPool(), validationEnabled);
  }
  public MachineConfigPoolBuilder(MachineConfigPoolFluent<?> fluent,MachineConfigPool instance) {
    this(fluent, instance, false);
  }
  public MachineConfigPoolBuilder(MachineConfigPoolFluent<?> fluent,MachineConfigPool instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new MachineConfigPool());

    if (instance != null) {
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
      fluent.withSpec(instance.getSpec());
      fluent.withStatus(instance.getStatus());
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
      fluent.withSpec(instance.getSpec());
      fluent.withStatus(instance.getStatus());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public MachineConfigPoolBuilder(MachineConfigPool instance) {
    this(instance,false);
  }
  public MachineConfigPoolBuilder(MachineConfigPool instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new MachineConfigPool());

    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
      this.withStatus(instance.getStatus());
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
      this.withStatus(instance.getStatus());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  MachineConfigPoolFluent<?> fluent;
  Boolean validationEnabled;
  public MachineConfigPool build() {
    MachineConfigPool buildable = new MachineConfigPool(fluent.getApiVersion(),fluent.getKind(),fluent.buildMetadata(),fluent.buildSpec(),fluent.buildStatus());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
